import os
from typing import List
from pathlib import Path

from jinja2 import Environment, FileSystemLoader


def build(*, src: str, dest: str, ext: List[str]):
    src_path = Path(src).resolve()
    dest_path = Path(dest).resolve()
    env = Environment(loader=FileSystemLoader(str(src)))
    if not dest_path.exists():
        os.makedirs(dest_path)
    for path in src_path.glob("**/*"):
        if path.name.startswith("_") or path.is_dir() or path.suffix not in ext:
            continue
        out_path = dest_path / path.relative_to(src_path)
        if not out_path.parent.exists():
            os.makedirs(out_path.parent)
        template_path = str(path.relative_to(src_path))
        print(f"{template_path} -> {out_path}")
        template = env.get_template(template_path)
        html = template.render()
        with open(out_path, "w", encoding="utf-8") as fl:
            fl.write(html)



import click

from . import builder


@click.group()
@click.option("--src", default="src", help="Where are the templates")
@click.option("--dest", default="public", help="Where should the output be placed")
@click.option(
    "-e",
    "--ext",
    default=[".html", ".txt"],
    help="What file extensions should we use. All others will be ignored.",
)
@click.pass_context
def cli(ctx, src, dest, ext):
    ctx.ensure_object(dict)
    ctx.obj["src"] = src
    ctx.obj["dest"] = dest
    ctx.obj["ext"] = dest


@cli.command()
@click.pass_context
def build(ctx):
    """
    Build the site.
    """
    builder.build(src=ctx.obj["src"], dest=ctx.obj["dest"], ext=ctx.obj["ext"])


if __name__ == "__main__":
    cli(obj={})
